@@ -192,7 +192,7 @@ def idl(**kwargs):
         #print('Your Input Geometry is invalid & may have issues:A valid Polygon may not possess anyoverlapping exterior or interior rings.'+'\n')
     date_filter = filters.date_range('acquired', gte=start,lte=end)
     cloud_filter = filters.range_filter('cloud_cover', gte=cmin,lte=cmax)
-    asset_filter=filters.permission_filter('assets.'+str(asset)+':download')
+    asset_filter=filters.permission_filter('assets.'+str(asset.split(',')[0])+':download')
     # print(rbase)
     # print(stbase)
     if len(rbase['field_name']) !=0 and len(stbase['field_name']) !=0:
@@ -208,33 +208,35 @@ def idl(**kwargs):
     res = client.quick_search(req)
     for things in res.items_iter(1000000): # A large number as max number to check against
         try:
-            itemid=things['id']
-            footprint = things["geometry"]
-            s = shape(footprint)
-            if item.startswith('SkySat'):
-                epsgcode='3857'
-            else:
-                epsgcode=things['properties']['epsg_code']
-            if aoi_shape.area>s.area:
-                intersect=(s).intersection(aoi_shape)
-            elif s.area>=aoi_shape.area:
-                intersect=(aoi_shape).intersection(s)
-            proj_transform = pyproj.Transformer.from_proj(pyproj.Proj(4326), pyproj.Proj(epsgcode), always_xy=True).transform # always_xy determines correct coord order
-            print('Processing ' + str(len(ar) + 1) + ' items with total area '+ str("{:,}".format(round(sum(far)))) + ' sqkm', end='\r')
-            if transform(proj_transform, (aoi_shape)).area>transform(proj_transform,s).area:
-                if (transform(proj_transform, intersect).area / transform(proj_transform, s).area*100)>=ovp:
-                    ar.append(transform(proj_transform, intersect).area/1000000)
-                    far.append(transform(proj_transform, s).area/1000000)
-                    with open(outfile,'a') as csvfile:
-                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
-                        writer.writerow([itemid])
-            elif transform(proj_transform, s).area>=transform(proj_transform, aoi_shape).area:
-                if (transform(proj_transform, intersect).area/transform(proj_transform, aoi_shape).area*100)>=ovp:
-                    ar.append(transform(proj_transform, intersect).area/1000000)
-                    far.append(transform(proj_transform, s).area/1000000)
-                    with open(outfile,'a') as csvfile:
-                        writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
-                        writer.writerow([itemid])
+            all_assets=[assets.split(':')[0].replace('assets.','') for assets in things['_permissions']]
+            if things['properties']['quality_category'] =='standard' and all(elem in all_assets for elem in asset.split(',')):
+                itemid=things['id']
+                footprint = things["geometry"]
+                s = shape(footprint)
+                if item.startswith('SkySat'):
+                    epsgcode='3857'
+                else:
+                    epsgcode=things['properties']['epsg_code']
+                if aoi_shape.area>s.area:
+                    intersect=(s).intersection(aoi_shape)
+                elif s.area>=aoi_shape.area:
+                    intersect=(aoi_shape).intersection(s)
+                proj_transform = pyproj.Transformer.from_proj(pyproj.Proj(4326), pyproj.Proj(epsgcode), always_xy=True).transform # always_xy determines correct coord order
+                print('Processing ' + str(len(ar) + 1) + ' items with total area '+ str("{:,}".format(round(sum(far)))) + ' sqkm', end='\r')
+                if transform(proj_transform, (aoi_shape)).area>transform(proj_transform,s).area:
+                    if (transform(proj_transform, intersect).area / transform(proj_transform, s).area*100)>=ovp:
+                        ar.append(transform(proj_transform, intersect).area/1000000)
+                        far.append(transform(proj_transform, s).area/1000000)
+                        with open(outfile,'a') as csvfile:
+                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
+                            writer.writerow([itemid])
+                elif transform(proj_transform, s).area>=transform(proj_transform, aoi_shape).area:
+                    if (transform(proj_transform, intersect).area/transform(proj_transform, aoi_shape).area*100)>=ovp:
+                        ar.append(transform(proj_transform, intersect).area/1000000)
+                        far.append(transform(proj_transform, s).area/1000000)
+                        with open(outfile,'a') as csvfile:
+                            writer=csv.writer(csvfile,delimiter=',',lineterminator='\n')
+                            writer.writerow([itemid])
             if int(len(ar))==int(num):
                 break
         except Exception as e:
