@@ -39,10 +39,10 @@ if str(platform.system().lower()) == "windows":
     version =sys.version_info[0]
     try:
         import pipwin
-        if pipwin.__version__=='0.4.9':
+        if pipwin.__version__=='0.5.0':
             pass
         else:
-            subprocess.call('python'+str(version)+' -m pip install pipwin==0.4.9', shell=True)
+            a=subprocess.call('{} -m pip install pipwin==0.5.0'.format(sys.executable), shell=True,stdout=subprocess.PIPE)
             subprocess.call('pipwin refresh', shell=True)
         '''Check if the pipwin cache is old: useful if you are upgrading porder on windows
         [This section looks if the pipwin cache is older than two weeks]
@@ -54,7 +54,7 @@ if str(platform.system().lower()) == "windows":
             print('Refreshing your pipwin cache')
             subprocess.call('pipwin refresh', shell=True)
     except ImportError:
-        subprocess.call('python'+str(version)+' -m pip install pipwin==0.4.9', shell=True)
+        a=subprocess.call('{} -m pip install pipwin==0.5.0'.format(sys.executable), shell=True,stdout=subprocess.PIPE)
         subprocess.call('pipwin refresh', shell=True)
     except Exception as e:
         print(e)
@@ -99,6 +99,7 @@ from .diffcheck import checker
 from .ordstat import ostat
 from .async_downloader import asyncdownload
 from .idcheck import idc
+from .resubmit import reorder
 from planet.api.auth import find_api_key
 if str(platform.python_version()) > "3.3.0":
     from .async_down import downloader
@@ -109,7 +110,15 @@ sys.path.append(lpath)
 
 # Get package version
 def porder_version():
-    print(pkg_resources.get_distribution("porder").version)
+    url='https://pypi.org/project/porder/'
+    source = requests.get(url)
+    html_content = source.text
+    soup = BeautifulSoup(html_content, "html.parser")
+    company = soup.find('h1')
+    if not pkg_resources.get_distribution("porder").version == company.string.strip().split(' ')[-1]:
+        print("\n"+"=========================================================================")
+        print('Current version of porder is {} upgrade to lastest version: {}'.format(pkg_resources.get_distribution("porder").version,company.string.strip().split(' ')[-1]))
+        print("=========================================================================")
 def version_from_parser(args):
     porder_version()
 
@@ -304,6 +313,10 @@ def order_from_parser(args):
         azure=args.azure,
         gcs=args.gcs)
 
+#Reorer an old or failed order
+def reorder_from_parser(args):
+    reorder(url=args.url, notification=args.notification)
+
 # Cancel an order or all order
 def cancel(id):
     headers = {'Content-Type': 'application/json'}
@@ -392,6 +405,8 @@ def multiproc_from_parser(args):
             subprocess.call("python multiproc_pydl.py "+args.url+" "+args.local+" ",shell=True)
         else:
             subprocess.call("python multiproc_pydl.py "+args.url+" "+args.local+" "+args.ext,shell=True)
+porder_version()
+print('')
 
 spacing="                               "
 
@@ -465,7 +480,8 @@ def main(args=None):
     parser_idcheck.add_argument('--idlist',help='Idlist csv file')
     parser_idcheck.add_argument('--item',help='Item type')
     parser_idcheck.add_argument('--asset',help='Asset type')
-    parser_idcheck.add_argument('--geometry',help='Geometry file for clip')
+    optional_named = parser_idcheck.add_argument_group('Optional named arguments')
+    optional_named.add_argument('--geometry', help="Geometry file for clip if any", default=None)
     parser_idcheck.set_defaults(func=idcheck_from_parser)
 
     parser_bundles = subparsers.add_parser('bundles',help='Check bundles of assets for given tiem type')
@@ -491,6 +507,13 @@ def main(args=None):
 
     parser_order.set_defaults(func=order_from_parser)
 
+    parser_reorder = subparsers.add_parser('reorder', help='Reorder an existing order')
+    required_named = parser_reorder.add_argument_group('Required named arguments.')
+    required_named.add_argument('--url', help='Order url to be ordered', required=True)
+    optional_named = parser_reorder.add_argument_group('Optional named arguments')
+    optional_named.add_argument('--notification', help='Use "email" to get an email notification',default=None)
+    parser_reorder.set_defaults(func=reorder_from_parser)
+
     parser_cancel = subparsers.add_parser('cancel',help='Cancel queued order(s)')
     parser_cancel.add_argument('--id',help='order id you want to cancel use "all" to cancel all')
     parser_cancel.set_defaults(func=cancel_from_parser)
